<?php
/**
 * Custom functions that act independently of the theme templates
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Catch_Store
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @since Catch Store Pro 1.0
 *
 * @param array $classes Classes for the body element.
 * @return array (Maybe) filtered body classes.
 */
function catch_store_body_classes( $classes ) {
	// Adds a class of custom-background-image to sites with a custom background image.
	if ( get_background_image() ) {
		$classes[] = 'custom-background-image';
	}

	// Adds a class of group-blog to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	// Always add a front-page class to the front page.
	if ( is_front_page() && ! is_home() ) {
		$classes[] = 'page-template-front-page';
	}

	// Adds a class of (full-width|box) to blogs.
	if ( 'boxed' === get_theme_mod( 'catch_store_layout_type' ) ) {
		$classes[] = 'boxed-layout';
	} else {
		$classes[] = 'fluid-layout';
	}

	// Adds a class with respect to layout selected.
	$layout  = catch_store_get_theme_layout();
	$sidebar = catch_store_get_sidebar_id();

	if ( 'no-sidebar' === $layout ) {
		$classes[] = 'no-sidebar content-width-layout';
	} elseif ( 'no-sidebar-full-width' === $layout ) {
		$classes[] = 'no-sidebar full-width-layout';
	} elseif ( 'left-sidebar' === $layout ) {
		if ( '' !== $sidebar ) {
			$classes[] = 'two-columns-layout content-right';
		}
	} elseif ( 'right-sidebar' === $layout ) {
		if ( '' !== $sidebar ) {
			$classes[] = 'two-columns-layout content-left';
		}
	}

	$header_media_title = get_theme_mod( 'catch_store_header_media_title', esc_html__( 'The Autumn Collection', 'catch-store-pro' ) );
	$header_media_text  = get_theme_mod( 'catch_store_header_media_text', esc_html__( 'Hypnotic Time of Autumn Falls', 'catch-store-pro' ) );

	if ( ! $header_media_title && ! $header_media_text ) {
		$classes[] = 'no-header-media-text';
	}

	if ( ! has_nav_menu( 'menu-2' ) ) {
		$classes[] = 'header-right-menu-disabled';
	}

	$header_right_search = get_theme_mod( 'catch_store_header_right_search_disable', 0 );
	if ( !has_nav_menu( 'social-header-right' ) && 1 == $header_right_search ) {
		$classes[] = 'header-center-layout';
	}

	$footer_text_align = get_theme_mod( 'catch_store_footer_text_align', 'left-align' );

	if ( 'right-align' === $footer_text_align ) {
		$classes[] = 'footer-right';
	} elseif ( 'center-align' === $footer_text_align ) {
		$classes[] = 'footer-center';
	} else {
		$classes[] = 'footer-left';
	}

	return $classes;
}
add_filter( 'body_class', 'catch_store_body_classes' );

/**
 * Add a pingback url auto-discovery header for singularly identifiable articles.
 */
function catch_store_pingback_header() {
	if ( is_singular() && pings_open() ) {
		echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
	}
}
add_action( 'wp_head', 'catch_store_pingback_header' );

if ( ! function_exists( 'catch_store_comment_form_fields' ) ) :
	/**
	 * Modify Comment Form Fields
	 *
	 * @uses comment_form_default_fields filter
	 * @since Catch Store Pro 1.0
	 */
	function catch_store_comment_form_fields( $fields ) {
	    $disable_website = get_theme_mod( 'catch_store_website_field' );

	    if ( isset( $fields['url'] ) && $disable_website ) {
			unset( $fields['url'] );
		}

		return $fields;
	}
endif; // catch_store_comment_form_fields.
add_filter( 'comment_form_default_fields', 'catch_store_comment_form_fields' );

/**
 * Adds font family custom CSS
 */
function catch_store_get_font_family_css() {
	$font_family_options = catch_store_font_family_options();

	$fonts = catch_store_avaliable_fonts();

	$css = array();

	foreach ( $font_family_options as $key => $value ) {
		$option = get_theme_mod( $key );
		if ( $option ) {
			$css[] = $value['selector'] . ' { font-family: ' . $fonts [ $option ]['label'] . '; }';
		}
	}

	$css = implode( PHP_EOL, $css );

	wp_add_inline_style( 'catch-store-style', $css );
}
add_action( 'wp_enqueue_scripts', 'catch_store_get_font_family_css', 11 );

/**
 * Remove first post from blog as it is already show via recent post template
 */
function catch_store_alter_home( $query ) {
	if ( $query->is_home() && $query->is_main_query() ) {
		$cats = get_theme_mod( 'catch_store_front_page_category' );

		if ( is_array( $cats ) && ! in_array( '0', $cats ) ) {
			$query->query_vars['category__in'] = $cats;
		}

		if ( get_theme_mod( 'catch_store_exclude_slider_post' ) ) {
			$quantity = get_theme_mod( 'catch_store_slider_number', 4 );

			$post_list	= array();	// list of valid post ids

			for( $i = 1; $i <= $quantity; $i++ ){
				if ( get_theme_mod( 'catch_store_slider_post_' . $i ) && get_theme_mod( 'catch_store_slider_post_' . $i ) > 0 ) {
					$post_list = array_merge( $post_list, array( get_theme_mod( 'catch_store_slider_post_' . $i ) ) );
				}
			}

			if ( ! empty( $post_list ) ) {
	    		$query->query_vars['post__not_in'] = $post_list;
			}
		}
	}
}
add_action( 'pre_get_posts', 'catch_store_alter_home' );

/**
 * Function to add Scroll Up icon
 */
function catch_store_scrollup() {
	$disable_scrollup = get_theme_mod( 'catch_store_disable_scrollup' );

	if ( $disable_scrollup ) {
		return;
	}

	echo '<a href="#masthead" id="scrollup" class="backtotop">' . catch_store_get_svg( array( 'icon' => 'angle-down' ) ) . '<span class="screen-reader-text">' . esc_html__( 'Scroll Up', 'catch-store-pro' ) . '</span></a>' ;

}
add_action( 'wp_footer', 'catch_store_scrollup', 1 );

if ( ! function_exists( 'catch_store_content_nav' ) ) :
	/**
	 * Display navigation/pagination when applicable
	 *
	 * @since Catch Store Pro 1.0
	 */
	function catch_store_content_nav() {
		global $wp_query;

		// Don't print empty markup in archives if there's only one page.
		if ( $wp_query->max_num_pages < 2 && ( is_home() || is_archive() || is_search() ) ) {
			return;
		}

		$pagination_type = get_theme_mod( 'catch_store_pagination_type', 'default' );

		/**
		 * Check if navigation type is Jetpack Infinite Scroll and if it is enabled, else goto default pagination
		 * if it's active then disable pagination
		 */
		if ( ( 'infinite-scroll' === $pagination_type ) && class_exists( 'Jetpack' ) && Jetpack::is_module_active( 'infinite-scroll' ) ) {
			return false;
		}

		if ( 'numeric' === $pagination_type && function_exists( 'the_posts_pagination' ) ) {
			the_posts_pagination( array(
				'prev_text'          => esc_html__( 'Previous', 'catch-store-pro' ),
				'next_text'          => esc_html__( 'Next', 'catch-store-pro' ),
				'before_page_number' => '<span class="meta-nav screen-reader-text">' . esc_html__( 'Page', 'catch-store-pro' ) . ' </span>',
			) );
		} else {
			the_posts_navigation();
		}
	}
endif; // catch_store_content_nav

/**
 * Check if a section is enabled or not based on the $value parameter
 * @param  string $value Value of the section that is to be checked
 * @return boolean return true if section is enabled otherwise false
 */
function catch_store_check_section( $value ) {
	global $wp_query;

	// Get Page ID outside Loop
	$page_id = $wp_query->get_queried_object_id();

	// Front page displays in Reading Settings
	$page_for_posts = get_option('page_for_posts');

	return ( 'entire-site' == $value  || ( ( is_front_page() || ( is_home() && intval( $page_for_posts ) !== intval( $page_id ) ) ) && 'homepage' == $value ) );
}

/**
 * Return the first image in a post. Works inside a loop.
 * @param [integer] $post_id [Post or page id]
 * @param [string/array] $size Image size. Either a string keyword (thumbnail, medium, large or full) or a 2-item array representing width and height in pixels, e.g. array(32,32).
 * @param [string/array] $attr Query string or array of attributes.
 * @return [string] image html
 *
 * @since Catch Store Pro 1.0
 */

function catch_store_get_first_image( $postID, $size, $attr ) {
	ob_start();

	ob_end_clean();

	$image 	= '';

	$output = preg_match_all('/<img.+src=[\'"]([^\'"]+)[\'"].*>/i', get_post_field('post_content', $postID ) , $matches);

	if( isset( $matches [1] [0] ) ) {
		//Get first image
		$first_img = $matches [1] [0];

		return '<img class="pngfix wp-post-image" src="'. esc_url( $first_img ) .'">';
	}

	return false;
}

function catch_store_get_theme_layout() {
	$layout = '';

	if ( is_page_template( 'templates/no-sidebar.php' ) ) {
		$layout = 'no-sidebar';
	} elseif ( is_page_template( 'templates/full-width-page.php' ) ) {
		$layout = 'no-sidebar-full-width';
	} elseif ( is_page_template( 'templates/left-sidebar.php' ) ) {
		$layout = 'left-sidebar';
	} elseif ( is_page_template( 'templates/right-sidebar.php' ) ) {
		$layout = 'right-sidebar';
	} else {
		$layout = get_theme_mod( 'catch_store_default_layout', 'right-sidebar' );

		if ( is_home() || is_archive() ) {
			$layout = get_theme_mod( 'catch_store_homepage_archive_layout', 'right-sidebar' );
		}

		if ( class_exists( 'WooCommerce' ) && ( is_shop() || is_woocommerce() || is_cart() || is_checkout() ) ) {
			$layout = get_theme_mod( 'catch_store_woocommerce_layout', 'no-sidebar' );
		}
	}

	return $layout;
}

function catch_store_get_sidebar_id() {
	$sidebar = '';

	$layout = catch_store_get_theme_layout();

	$sidebaroptions = '';

	if ( 'no-sidebar-full-width' === $layout || 'no-sidebar' === $layout ) {
		return $sidebar;
	}

	// WooCommerce Shop Page excluding Cart and checkout.
	if ( class_exists( 'WooCommerce' ) && is_woocommerce() ) {
		$shop_id        = get_option( 'woocommerce_shop_page_id' );
		$sidebaroptions = get_post_meta( $shop_id, 'catch-store-sidebar-option', true );
	} else {
		global $post, $wp_query;

		// Front page displays in Reading Settings.
		$page_on_front  = get_option( 'page_on_front' );
		$page_for_posts = get_option( 'page_for_posts' );

		// Get Page ID outside Loop.
		$page_id = $wp_query->get_queried_object_id();
		// Blog Page or Front Page setting in Reading Settings.
		if ( $page_id == $page_for_posts || $page_id == $page_on_front ) {
	        $sidebaroptions = get_post_meta( $page_id, 'catch-store-sidebar-option', true );
	    } elseif ( is_singular() ) {
	    	if ( is_attachment() ) {
				$parent 		= $post->post_parent;
				$sidebaroptions = get_post_meta( $parent, 'catch-store-sidebar-option', true );

			} else {
				$sidebaroptions = get_post_meta( $post->ID, 'catch-store-sidebar-option', true );
			}
		}
	}

	if ( is_active_sidebar( 'sidebar-6' ) && class_exists( 'WooCommerce' ) && ( is_woocommerce() || is_cart() || is_checkout() ) ) {
		$sidebar = 'sidebar-woo'; // WooCommerce Sidebar.
	} elseif ( is_active_sidebar( 'sidebar-optional-one' ) && 'optional-sidebar-one' === $sidebaroptions ) {
		$sidebar = 'sidebar-optional-one';
	} elseif ( is_active_sidebar( 'sidebar-optional-two' ) && 'optional-sidebar-two' === $sidebaroptions ) {
		$sidebar = 'sidebar-optional-two';
	} elseif ( is_active_sidebar( 'sidebar-optional-three' ) && 'optional-sidebar-three' === $sidebaroptions ) {
		$sidebar = 'sidebar-optional-three';
	} elseif ( is_active_sidebar( 'sidebar-optional-homepage' ) && ( is_front_page() || ( is_home() && $page_id != $page_for_posts ) ) ) {
		$sidebar = 'sidebar-optional-homepage';
	} elseif ( is_active_sidebar( 'sidebar-optional-archive' ) && ( is_archive() || ( is_home() && $page_id != $page_for_posts ) ) ) {
		$sidebar = 'sidebar-optional-archive';
	} elseif ( is_page() && is_active_sidebar( 'sidebar-optional-page' ) ) {
		$sidebar = 'sidebar-optional-page';
	} elseif ( is_single() && is_active_sidebar( 'sidebar-optional-post' ) ) {
		$sidebar = 'sidebar-optional-post';
	} elseif ( is_active_sidebar( 'sidebar-1' ) ) {
		$sidebar = 'sidebar-1'; // Primary Sidebar.
	}

	return $sidebar;
}

/**
 * Display social Menu
 */
function catch_store_social_menu() {
	if ( has_nav_menu( 'social-menu' ) ) :
		?>
		<nav class="social-navigation" role="navigation" aria-label="<?php esc_attr_e( 'Social Links Menu', 'catch-store-pro' ); ?>">
			<?php
				wp_nav_menu( array(
					'theme_location' => 'social-menu',
					'link_before'    => '<span class="screen-reader-text">',
					'link_after'     => '</span>',
					'depth'          => 1,
				) );
			?>
		</nav><!-- .social-navigation -->
	<?php endif;
}

if ( ! function_exists( 'catch_store_truncate_phrase' ) ) :
	/**
	 * Return a phrase shortened in length to a maximum number of characters.
	 *
	 * Result will be truncated at the last white space in the original string. In this function the word separator is a
	 * single space. Other white space characters (like newlines and tabs) are ignored.
	 *
	 * If the first `$max_characters` of the string does not contain a space character, an empty string will be returned.
	 *
	 * @since Catch Store Pro 1.0
	 *
	 * @param string $text            A string to be shortened.
	 * @param integer $max_characters The maximum number of characters to return.
	 *
	 * @return string Truncated string
	 */
	function catch_store_truncate_phrase( $text, $max_characters ) {

		$text = trim( $text );

		if ( mb_strlen( $text ) > $max_characters ) {
			//* Truncate $text to $max_characters + 1
			$text = mb_substr( $text, 0, $max_characters + 1 );

			//* Truncate to the last space in the truncated string
			$text = trim( mb_substr( $text, 0, mb_strrpos( $text, ' ' ) ) );
		}

		return $text;
	}
endif; //catch-catch_store_truncate_phrase

if ( ! function_exists( 'catch_store_get_the_content_limit' ) ) :
	/**
	 * Return content stripped down and limited content.
	 *
	 * Strips out tags and shortcodes, limits the output to `$max_char` characters, and appends an ellipsis and more link to the end.
	 *
	 * @since Catch Store Pro 1.0
	 *
	 * @param integer $max_characters The maximum number of characters to return.
	 * @param string  $more_link_text Optional. Text of the more link. Default is "(more...)".
	 * @param bool    $stripteaser    Optional. Strip teaser content before the more text. Default is false.
	 *
	 * @return string Limited content.
	 */
	function catch_store_get_the_content_limit( $max_characters, $more_link_text = '(more...)', $stripteaser = false ) {

		$content = get_the_content( '', $stripteaser );

		// Strip tags and shortcodes so the content truncation count is done correctly.
		$content = strip_tags( strip_shortcodes( $content ), apply_filters( 'get_the_content_limit_allowedtags', '<script>,<style>' ) );

		// Remove inline styles / .
		$content = trim( preg_replace( '#<(s(cript|tyle)).*?</\1>#si', '', $content ) );

		// Truncate $content to $max_char
		$content = catch_store_truncate_phrase( $content, $max_characters );

		// More link?
		if ( $more_link_text ) {
			$link   = apply_filters( 'get_the_content_more_link', sprintf( '<span class="more-button"><a href="%s" class="more-link">%s</a></span>', esc_url( get_permalink() ), $more_link_text ), $more_link_text );
			$output = sprintf( '<p>%s %s</p>', $content, $link );
		} else {
			$output = sprintf( '<p>%s</p>', $content );
			$link = '';
		}

		return apply_filters( 'catch_store_get_the_content_limit', $output, $content, $link, $max_characters );

	}
endif; //catch-catch_store_get_the_content_limit

if ( ! function_exists( 'catch_store_content_image' ) ) :
	/**
	 * Template for Featured Image in Archive Content
	 *
	 * To override this in a child theme
	 * simply fabulous-fluid your own catch_store_content_image(), and that function will be used instead.
	 *
	 * @since Catch Store Pro 1.0
	 */
	function catch_store_content_image() {
		if ( has_post_thumbnail() && catch_store_jetpack_featured_image_display() && is_singular() ) {
			global $post, $wp_query;

			// Get Page ID outside Loop.
			$page_id = $wp_query->get_queried_object_id();

			if ( $post ) {
		 		if ( is_attachment() ) {
					$parent = $post->post_parent;

					$individual_featured_image = get_post_meta( $parent, 'catch-store-single-image', true );
				} else {
					$individual_featured_image = get_post_meta( $page_id, 'catch-store-single-image', true );
				}
			}

			if ( empty( $individual_featured_image ) ) {
				$individual_featured_image = 'default';
			}

			if ( 'disable' === $individual_featured_image ) {
				echo '<!-- Page/Post Single Image Disabled or No Image set in Post Thumbnail -->';
				return false;
			} else {
				$class = array();

				$image_size = 'post-thumbnail';

				if ( 'default' !== $individual_featured_image ) {
					$image_size = $individual_featured_image;
					$class[]    = 'from-metabox';
				} else {
					$layout = catch_store_get_theme_layout();

					if ( 'no-sidebar-full-width' === $layout ) {
						$image_size = 'catch-store-slider';
					}
				}

				$class[] = $individual_featured_image;
				?>
				<div class="post-thumbnail <?php echo esc_attr( implode( ' ', $class ) ); ?>">
					<a href="<?php the_permalink(); ?>">
					<?php the_post_thumbnail( $image_size ); ?>
					</a>
				</div>
		   	<?php
			}
		} // End if().
	}
endif; // catch_store_content_image.

if ( ! function_exists( 'catch_store_enable_homepage_posts' ) ) :
    /**
     * Determine Homepage Content disabled or not
     * @return boolean
     */
    function catch_store_enable_homepage_posts() {
       if ( ! ( get_theme_mod( 'catch_store_disable_homepage_posts' ) && is_front_page() ) ) {
            return true;
        }
        return false;
    }
endif; // catch_store_enable_homepage_posts.

if ( ! function_exists( 'catch_store_enable_header_contact' ) ) :
    /**
     * Determine Homepage Content disabled or not
     * @return boolean
     */
    function catch_store_enable_header_contact() {
    	$date    = get_theme_mod( 'catch_store_enable_date' );
		$email   = get_theme_mod( 'catch_store_email' );
		$address = get_theme_mod( 'catch_store_address' );
		$phone   = get_theme_mod( 'catch_store_phone' );

       if ( $date || $email  || $address || $phone ) {
            return true;
        }
        return false;
    }
endif; // catch_store_enable_homepage_posts.


/**
 * Get Featured Posts
 */

function catch_store_get_posts( $section ) {
	$type   = get_theme_mod( 'catch_store_featured_content_type', 'demo' );
	$number = get_theme_mod( 'catch_store_featured_content_number', 4 );

	if ( 'featured_content' === $section ) {
		$type     = get_theme_mod( 'catch_store_featured_content_type', 'demo' );
		$number   = get_theme_mod( 'catch_store_featured_content_number', 4 );
		$cpt_slug = 'featured-content';
	} elseif ( 'portfolio' === $section ) {
		$type     = get_theme_mod( 'catch_store_portfolio_type', 'demo' );
		$number   = get_theme_mod( 'catch_store_portfolio_number', 5 );
		$cpt_slug = 'jetpack-portfolio';
	} elseif ( 'team' === $section ) {
		$type     = get_theme_mod( 'catch_store_team_type', 'demo' );
		$number   = get_theme_mod( 'catch_store_team_number', 4 );
		$cpt_slug = ''; // Event has no cpt.
	} elseif ( 'stats' === $section ) {
		$type     = get_theme_mod( 'catch_store_stats_type', 'demo' );
		$number   = get_theme_mod( 'catch_store_stats_number', 4 );
		$cpt_slug = ''; // Event has no cpt.
	} elseif ( 'testimonial' === $section ) {
		$type     = get_theme_mod( 'catch_store_testimonial_type', 'demo' );
		$number   = get_theme_mod( 'catch_store_testimonial_number', 4 );
		$cpt_slug = 'jetpack-testimonial';
	}

	$post_list  = array();
	$no_of_post = 0;

	$args = array(
		'post_type'           => 'post',
		'ignore_sticky_posts' => 1, // ignore sticky posts.
	);

	// Get valid number of posts.
	if ( 'post' === $type || 'page' === $type || $cpt_slug === $type ) {
		$args['post_type'] = $type;

		for ( $i = 1; $i <= $number; $i++ ) {
			$post_id = '';

			if ( 'post' === $type ) {
				$post_id = get_theme_mod( 'catch_store_' . $section . '_post_' . $i );
			} elseif ( 'page' === $type ) {
				$post_id = get_theme_mod( 'catch_store_' . $section . '_page_' . $i );
			} elseif ( $cpt_slug === $type ) {
				$post_id = get_theme_mod( 'catch_store_' . $section . '_cpt_' . $i );
			}

			if ( $post_id && '' !== $post_id ) {
				$post_list = array_merge( $post_list, array( $post_id ) );

				$no_of_post++;
			}
		}

		$args['post__in'] = $post_list;
		$args['orderby']  = 'post__in';
	} elseif ( 'category' === $type ) {
		if ( $cat = get_theme_mod( 'catch_store_' . $section . '_select_category' ) ) {
			$args['category__in'] = $cat;
		}


		$no_of_post = $number;
	}

	$args['posts_per_page'] = $no_of_post;

	if( ! $no_of_post ) {
		return;
	}

	$posts = get_posts( $args );

	return $posts;
}

if ( ! function_exists( 'catch_store_sections' ) ) :
	/**
	 * Display Sections on header and footer with respect to the section option set in catch_store_sections_sort
	 */
	function catch_store_sections( $selector = 'header' ) {
		$sections = get_theme_mod( 'catch_store_sections_sort', catch_store_get_default_sections_value() );

		$separated_sections = explode( 'main-content,', $sections );

		$sections = $separated_sections[0];

		if ( 'footer' === $selector ) {
			$sections = $separated_sections[1];
		}

		$sections = explode( ',', $sections );

		foreach ( $sections as $section ) {
			if ( 'header-media' === $section ) {
				get_template_part( 'template-parts/header/header', 'media' );
			} elseif ( 'breadcrumb' === $section ) {
				get_template_part( 'template-parts/header/breadcrumb' );
			} elseif ( 'slider' === $section ) {
				get_template_part( 'template-parts/slider/content', 'slider' );
			} elseif ( 'recent-products' ===  $section  ) {
				get_template_part( 'template-parts/woo-products-showcase/recent', 'products' );
			} elseif ( 'top-rated-products' ===  $section  ) {
				get_template_part( 'template-parts/woo-products-showcase/toprated', 'products' );
			} elseif ( 'sale-products' ===  $section  ) {
				get_template_part( 'template-parts/woo-products-showcase/sale', 'products' );
			} elseif ( 'product-review' ===  $section  ) {
				get_template_part( 'template-parts/product-review/product', 'review' );
			} elseif ( 'featured-content' === $section ) {
				get_template_part( 'template-parts/featured-content/display','featured' );
			} elseif ( 'hero-content' === $section ) {
				get_template_part( 'template-parts/hero-content/content','hero' );
			} elseif ( 'portfolio' === $section ) {
				get_template_part('template-parts/portfolio/display','portfolio');
			} elseif ( 'testimonial' === $section ) {
				get_template_part( 'template-parts/testimonial/display', 'testimonial' );
			} elseif ( 'team' === $section ) {
				get_template_part( 'template-parts/team/display', 'team' );
			} elseif ( 'service' === $section ) {
				get_template_part( 'template-parts/service/content', 'service' );
			} elseif ( 'stats' === $section ) {
				get_template_part( 'template-parts/stats/display', 'stats' );
			} elseif ( 'recent-posts' ===  $section  ) {
				if ( 'page' == get_option('show_on_front') && is_front_page() && get_theme_mod( 'catch_store_enable_static_page_posts' ) )  {
					get_template_part( 'template-parts/recent-posts/front-recent', 'posts' );
				}
			} elseif ( 'promotion-headline' ===  $section  ) {
				get_template_part( 'template-parts/promotion-headline/content', 'promotion' );
			}
		}
	}
endif;

if ( ! function_exists( 'catch_store_get_sortable_sections' ) ) :
	/**
	 * Returns list of sortable sections
	 */
	function catch_store_get_sortable_sections() {
		$sortable_sections = array(
			'header-media'           => array(
				'label'   => esc_html__( 'Header Media', 'catch-store-pro' ),
				'section' => 'header_image'
			),
			'breadcrumb'             => array(
				'label'   => esc_html__( 'Breadcrumb', 'catch-store-pro' ),
				'section' => 'catch_store_breadcrumb_options'
			),
			'slider'                 => array(
				'label'   => esc_html__( 'Slider', 'catch-store-pro' ),
				'section' => 'catch_store_featured_slider'
			),
			'recent-products'        => array(
				'label'   => esc_html__( 'Recent Products', 'catch-store-pro' ),
				'section' => 'catch_store_recent_products_showcase'
			),
			'top-rated-products'     => array(
				'label'   => esc_html__( 'Top Rated Products', 'catch-store-pro' ),
				'section' => 'catch_store_top_rated_products_showcase'
			),
			'sale-products'     => array(
				'label'   => esc_html__( 'Sale Products', 'catch-store-pro' ),
				'section' => 'catch_store_sale_products_showcase'
			),
			'hero-content'           => array(
				'label'   => esc_html__( 'Hero Content', 'catch-store-pro' ),
				'section' => 'catch_store_hero_content_options'
			),
			'portfolio'              => array(
				'label'   => esc_html__( 'Portfolio', 'catch-store-pro' ),
				'section' => 'catch_store_portfolio'
			),
			'promotion-headline'     => array(
				'label'   => esc_html__( 'Promotion headline', 'catch-store-pro' ),
				'section' => 'catch_store_promotion_headline'
			),
			'stats'                 => array(
				'label'   => esc_html__( 'Stats', 'catch-store-pro' ),
				'section' => 'catch_store_stats'
			),
			'testimonial'            => array(
				'label'   => esc_html__( 'Testimonial', 'catch-store-pro' ),
				'section' => 'catch_store_testimonials'
			),
			'product-review'            => array(
				'label'   => esc_html__( 'Products Review', 'catch-store-pro' ),
				'section' => 'catch_store_products_review'
			),
			'team'                   => array(
				'label'   => esc_html__( 'Team', 'catch-store-pro' ),
				'section' => 'catch_store_team'
			),
			'featured-content'       => array(
				'label'   => esc_html__( 'Featured Content', 'catch-store-pro' ),
				'section' => 'catch_store_featured_content'
			),
			'main-content'           => array(
				'label'   => esc_html__( 'Main Content', 'catch-store-pro' ),
			),
			'recent-posts'           => array(
				'label'   => esc_html__( 'Recent Posts ( Only on homepage )', 'catch-store-pro' ),
				'section' => 'catch_store_homepage_options'
			),
		);

		return $sortable_sections;
	}
endif;

function catch_store_team_social( $link ) {
    // Get supported social icons.
    $social_icons = catch_store_social_links_icons();

    foreach ( $social_icons as $attr => $value ) {
        if ( false !== strpos( $link, $attr ) ) {
            return catch_store_get_svg( array( 'icon' => esc_attr( $value ) ) );
        }
    }
}

if ( ! function_exists( 'catch_store_team_social_links' ) ) :
	/**
	 * Displays team social links html
	 */
	function catch_store_team_social_links( $counter ) {
		?>
		<div class="artist-social-profile">
            <nav class="social-navigation" role="navigation" aria-label="Social Menu">
                <div class="menu-social-container">
                    <ul id="menu-social-menu" class="social-links-menu">
				        <?php
				        $social_link_one = get_theme_mod( 'catch_store_team_social_link_one_' . $counter );

				    	if ( $social_link_one ): ?>
				            <li class="menu-item-one">
				            	<?php $link_one =  catch_store_team_social( $social_link_one ); ?>
				                <a target="_blank" rel="nofollow" href="<?php echo esc_url( $social_link_one ); ?>"><?php echo ( $link_one ); ?></a>
				            </li>
				    	<?php endif;  ?>

						<?php
				    	$social_link_two = get_theme_mod( 'catch_store_team_social_link_two_' . $counter );
				    	if ( $social_link_two ): ?>
				            <li class="menu-item-two">
				            	<?php $link_two =  catch_store_team_social( $social_link_two ); ?>
				                <a target="_blank" rel="nofollow" href="<?php echo esc_url( $social_link_two ); ?>"><?php echo ( $link_two ); ?></a>
				            </li>
				    	<?php endif;  ?>

				    	<?php
				    	$social_link_three = get_theme_mod( 'catch_store_team_social_link_three_' . $counter );
				    	if ( $social_link_three ): ?>
				            <li class="menu-item-three">
				            	<?php $link_three =  catch_store_team_social( $social_link_three ); ?>
				                <a target="_blank" rel="nofollow" href="<?php echo esc_url( $social_link_three ); ?>"><?php echo ( $link_three ); ?></a>
				            </li>
				    	<?php endif;  ?>

				    	<?php
				    	$social_link_four = get_theme_mod( 'catch_store_team_social_link_four_' . $counter );
				    	if ( $social_link_four ): ?>
				            <li class="menu-item-four">
				            	<?php $link_four =  catch_store_team_social( $social_link_four ); ?>
				                <a target="_blank" rel="nofollow" href="<?php echo esc_url( $social_link_four ); ?>"><?php echo ( $link_four ); ?></a>
				            </li>
				    	<?php endif; ?>
				    </ul>
				</div>
			</nav>
		</div><!-- .artist-social-profile -->
		<?php
	}
endif;